"""Subpackage."""

from typing import TYPE_CHECKING as __tc


if __tc:
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3599 import (
        AbstractAssemblySteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3600 import (
        AbstractShaftOrHousingSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3601 import (
        AbstractShaftSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3602 import (
        AbstractShaftToMountableComponentConnectionSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3603 import (
        AGMAGleasonConicalGearMeshSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3604 import (
        AGMAGleasonConicalGearSetSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3605 import (
        AGMAGleasonConicalGearSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3606 import (
        AssemblySteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3607 import (
        BearingSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3608 import (
        BeltConnectionSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3609 import (
        BeltDriveSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3610 import (
        BevelDifferentialGearMeshSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3611 import (
        BevelDifferentialGearSetSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3612 import (
        BevelDifferentialGearSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3613 import (
        BevelDifferentialPlanetGearSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3614 import (
        BevelDifferentialSunGearSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3615 import (
        BevelGearMeshSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3616 import (
        BevelGearSetSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3617 import (
        BevelGearSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3618 import (
        BoltedJointSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3619 import (
        BoltSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3620 import (
        ClutchConnectionSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3621 import (
        ClutchHalfSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3622 import (
        ClutchSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3623 import (
        CoaxialConnectionSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3624 import (
        ComponentSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3625 import (
        ConceptCouplingConnectionSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3626 import (
        ConceptCouplingHalfSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3627 import (
        ConceptCouplingSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3628 import (
        ConceptGearMeshSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3629 import (
        ConceptGearSetSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3630 import (
        ConceptGearSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3631 import (
        ConicalGearMeshSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3632 import (
        ConicalGearSetSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3633 import (
        ConicalGearSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3634 import (
        ConnectionSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3635 import (
        ConnectorSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3636 import (
        CouplingConnectionSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3637 import (
        CouplingHalfSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3638 import (
        CouplingSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3639 import (
        CVTBeltConnectionSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3640 import (
        CVTPulleySteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3641 import (
        CVTSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3642 import (
        CycloidalAssemblySteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3643 import (
        CycloidalDiscCentralBearingConnectionSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3644 import (
        CycloidalDiscPlanetaryBearingConnectionSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3645 import (
        CycloidalDiscSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3646 import (
        CylindricalGearMeshSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3647 import (
        CylindricalGearSetSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3648 import (
        CylindricalGearSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3649 import (
        CylindricalPlanetGearSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3650 import (
        DatumSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3651 import (
        ExternalCADModelSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3652 import (
        FaceGearMeshSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3653 import (
        FaceGearSetSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3654 import (
        FaceGearSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3655 import (
        FEPartSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3656 import (
        FlexiblePinAssemblySteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3657 import (
        GearMeshSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3658 import (
        GearSetSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3659 import (
        GearSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3660 import (
        GuideDxfModelSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3661 import (
        HypoidGearMeshSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3662 import (
        HypoidGearSetSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3663 import (
        HypoidGearSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3664 import (
        InterMountableComponentConnectionSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3665 import (
        KlingelnbergCycloPalloidConicalGearMeshSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3666 import (
        KlingelnbergCycloPalloidConicalGearSetSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3667 import (
        KlingelnbergCycloPalloidConicalGearSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3668 import (
        KlingelnbergCycloPalloidHypoidGearMeshSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3669 import (
        KlingelnbergCycloPalloidHypoidGearSetSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3670 import (
        KlingelnbergCycloPalloidHypoidGearSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3671 import (
        KlingelnbergCycloPalloidSpiralBevelGearMeshSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3672 import (
        KlingelnbergCycloPalloidSpiralBevelGearSetSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3673 import (
        KlingelnbergCycloPalloidSpiralBevelGearSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3674 import (
        MassDiscSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3675 import (
        MeasurementComponentSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3676 import (
        MicrophoneArraySteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3677 import (
        MicrophoneSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3678 import (
        MountableComponentSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3679 import (
        OilSealSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3680 import (
        PartSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3681 import (
        PartToPartShearCouplingConnectionSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3682 import (
        PartToPartShearCouplingHalfSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3683 import (
        PartToPartShearCouplingSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3684 import (
        PlanetaryConnectionSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3685 import (
        PlanetaryGearSetSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3686 import (
        PlanetCarrierSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3687 import (
        PointLoadSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3688 import (
        PowerLoadSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3689 import (
        PulleySteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3690 import (
        RingPinsSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3691 import (
        RingPinsToDiscConnectionSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3692 import (
        RollingRingAssemblySteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3693 import (
        RollingRingConnectionSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3694 import (
        RollingRingSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3695 import (
        RootAssemblySteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3696 import (
        ShaftHubConnectionSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3697 import (
        ShaftSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3698 import (
        ShaftToMountableComponentConnectionSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3699 import (
        SpecialisedAssemblySteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3700 import (
        SpiralBevelGearMeshSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3701 import (
        SpiralBevelGearSetSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3702 import (
        SpiralBevelGearSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3703 import (
        SpringDamperConnectionSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3704 import (
        SpringDamperHalfSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3705 import (
        SpringDamperSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3706 import (
        SteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3707 import (
        StraightBevelDiffGearMeshSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3708 import (
        StraightBevelDiffGearSetSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3709 import (
        StraightBevelDiffGearSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3710 import (
        StraightBevelGearMeshSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3711 import (
        StraightBevelGearSetSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3712 import (
        StraightBevelGearSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3713 import (
        StraightBevelPlanetGearSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3714 import (
        StraightBevelSunGearSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3715 import (
        SynchroniserHalfSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3716 import (
        SynchroniserPartSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3717 import (
        SynchroniserSleeveSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3718 import (
        SynchroniserSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3719 import (
        TorqueConverterConnectionSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3720 import (
        TorqueConverterPumpSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3721 import (
        TorqueConverterSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3722 import (
        TorqueConverterTurbineSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3723 import (
        UnbalancedMassSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3724 import (
        VirtualComponentSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3725 import (
        WormGearMeshSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3726 import (
        WormGearSetSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3727 import (
        WormGearSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3728 import (
        ZerolBevelGearMeshSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3729 import (
        ZerolBevelGearSetSteadyStateSynchronousResponseAtASpeed,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3730 import (
        ZerolBevelGearSteadyStateSynchronousResponseAtASpeed,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3599": [
            "AbstractAssemblySteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3600": [
            "AbstractShaftOrHousingSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3601": [
            "AbstractShaftSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3602": [
            "AbstractShaftToMountableComponentConnectionSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3603": [
            "AGMAGleasonConicalGearMeshSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3604": [
            "AGMAGleasonConicalGearSetSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3605": [
            "AGMAGleasonConicalGearSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3606": [
            "AssemblySteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3607": [
            "BearingSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3608": [
            "BeltConnectionSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3609": [
            "BeltDriveSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3610": [
            "BevelDifferentialGearMeshSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3611": [
            "BevelDifferentialGearSetSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3612": [
            "BevelDifferentialGearSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3613": [
            "BevelDifferentialPlanetGearSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3614": [
            "BevelDifferentialSunGearSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3615": [
            "BevelGearMeshSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3616": [
            "BevelGearSetSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3617": [
            "BevelGearSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3618": [
            "BoltedJointSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3619": [
            "BoltSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3620": [
            "ClutchConnectionSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3621": [
            "ClutchHalfSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3622": [
            "ClutchSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3623": [
            "CoaxialConnectionSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3624": [
            "ComponentSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3625": [
            "ConceptCouplingConnectionSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3626": [
            "ConceptCouplingHalfSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3627": [
            "ConceptCouplingSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3628": [
            "ConceptGearMeshSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3629": [
            "ConceptGearSetSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3630": [
            "ConceptGearSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3631": [
            "ConicalGearMeshSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3632": [
            "ConicalGearSetSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3633": [
            "ConicalGearSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3634": [
            "ConnectionSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3635": [
            "ConnectorSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3636": [
            "CouplingConnectionSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3637": [
            "CouplingHalfSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3638": [
            "CouplingSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3639": [
            "CVTBeltConnectionSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3640": [
            "CVTPulleySteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3641": [
            "CVTSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3642": [
            "CycloidalAssemblySteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3643": [
            "CycloidalDiscCentralBearingConnectionSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3644": [
            "CycloidalDiscPlanetaryBearingConnectionSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3645": [
            "CycloidalDiscSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3646": [
            "CylindricalGearMeshSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3647": [
            "CylindricalGearSetSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3648": [
            "CylindricalGearSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3649": [
            "CylindricalPlanetGearSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3650": [
            "DatumSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3651": [
            "ExternalCADModelSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3652": [
            "FaceGearMeshSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3653": [
            "FaceGearSetSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3654": [
            "FaceGearSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3655": [
            "FEPartSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3656": [
            "FlexiblePinAssemblySteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3657": [
            "GearMeshSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3658": [
            "GearSetSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3659": [
            "GearSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3660": [
            "GuideDxfModelSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3661": [
            "HypoidGearMeshSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3662": [
            "HypoidGearSetSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3663": [
            "HypoidGearSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3664": [
            "InterMountableComponentConnectionSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3665": [
            "KlingelnbergCycloPalloidConicalGearMeshSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3666": [
            "KlingelnbergCycloPalloidConicalGearSetSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3667": [
            "KlingelnbergCycloPalloidConicalGearSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3668": [
            "KlingelnbergCycloPalloidHypoidGearMeshSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3669": [
            "KlingelnbergCycloPalloidHypoidGearSetSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3670": [
            "KlingelnbergCycloPalloidHypoidGearSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3671": [
            "KlingelnbergCycloPalloidSpiralBevelGearMeshSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3672": [
            "KlingelnbergCycloPalloidSpiralBevelGearSetSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3673": [
            "KlingelnbergCycloPalloidSpiralBevelGearSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3674": [
            "MassDiscSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3675": [
            "MeasurementComponentSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3676": [
            "MicrophoneArraySteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3677": [
            "MicrophoneSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3678": [
            "MountableComponentSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3679": [
            "OilSealSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3680": [
            "PartSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3681": [
            "PartToPartShearCouplingConnectionSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3682": [
            "PartToPartShearCouplingHalfSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3683": [
            "PartToPartShearCouplingSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3684": [
            "PlanetaryConnectionSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3685": [
            "PlanetaryGearSetSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3686": [
            "PlanetCarrierSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3687": [
            "PointLoadSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3688": [
            "PowerLoadSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3689": [
            "PulleySteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3690": [
            "RingPinsSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3691": [
            "RingPinsToDiscConnectionSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3692": [
            "RollingRingAssemblySteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3693": [
            "RollingRingConnectionSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3694": [
            "RollingRingSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3695": [
            "RootAssemblySteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3696": [
            "ShaftHubConnectionSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3697": [
            "ShaftSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3698": [
            "ShaftToMountableComponentConnectionSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3699": [
            "SpecialisedAssemblySteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3700": [
            "SpiralBevelGearMeshSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3701": [
            "SpiralBevelGearSetSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3702": [
            "SpiralBevelGearSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3703": [
            "SpringDamperConnectionSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3704": [
            "SpringDamperHalfSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3705": [
            "SpringDamperSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3706": [
            "SteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3707": [
            "StraightBevelDiffGearMeshSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3708": [
            "StraightBevelDiffGearSetSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3709": [
            "StraightBevelDiffGearSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3710": [
            "StraightBevelGearMeshSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3711": [
            "StraightBevelGearSetSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3712": [
            "StraightBevelGearSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3713": [
            "StraightBevelPlanetGearSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3714": [
            "StraightBevelSunGearSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3715": [
            "SynchroniserHalfSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3716": [
            "SynchroniserPartSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3717": [
            "SynchroniserSleeveSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3718": [
            "SynchroniserSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3719": [
            "TorqueConverterConnectionSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3720": [
            "TorqueConverterPumpSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3721": [
            "TorqueConverterSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3722": [
            "TorqueConverterTurbineSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3723": [
            "UnbalancedMassSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3724": [
            "VirtualComponentSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3725": [
            "WormGearMeshSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3726": [
            "WormGearSetSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3727": [
            "WormGearSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3728": [
            "ZerolBevelGearMeshSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3729": [
            "ZerolBevelGearSetSteadyStateSynchronousResponseAtASpeed"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses_at_a_speed._3730": [
            "ZerolBevelGearSteadyStateSynchronousResponseAtASpeed"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "AbstractAssemblySteadyStateSynchronousResponseAtASpeed",
    "AbstractShaftOrHousingSteadyStateSynchronousResponseAtASpeed",
    "AbstractShaftSteadyStateSynchronousResponseAtASpeed",
    "AbstractShaftToMountableComponentConnectionSteadyStateSynchronousResponseAtASpeed",
    "AGMAGleasonConicalGearMeshSteadyStateSynchronousResponseAtASpeed",
    "AGMAGleasonConicalGearSetSteadyStateSynchronousResponseAtASpeed",
    "AGMAGleasonConicalGearSteadyStateSynchronousResponseAtASpeed",
    "AssemblySteadyStateSynchronousResponseAtASpeed",
    "BearingSteadyStateSynchronousResponseAtASpeed",
    "BeltConnectionSteadyStateSynchronousResponseAtASpeed",
    "BeltDriveSteadyStateSynchronousResponseAtASpeed",
    "BevelDifferentialGearMeshSteadyStateSynchronousResponseAtASpeed",
    "BevelDifferentialGearSetSteadyStateSynchronousResponseAtASpeed",
    "BevelDifferentialGearSteadyStateSynchronousResponseAtASpeed",
    "BevelDifferentialPlanetGearSteadyStateSynchronousResponseAtASpeed",
    "BevelDifferentialSunGearSteadyStateSynchronousResponseAtASpeed",
    "BevelGearMeshSteadyStateSynchronousResponseAtASpeed",
    "BevelGearSetSteadyStateSynchronousResponseAtASpeed",
    "BevelGearSteadyStateSynchronousResponseAtASpeed",
    "BoltedJointSteadyStateSynchronousResponseAtASpeed",
    "BoltSteadyStateSynchronousResponseAtASpeed",
    "ClutchConnectionSteadyStateSynchronousResponseAtASpeed",
    "ClutchHalfSteadyStateSynchronousResponseAtASpeed",
    "ClutchSteadyStateSynchronousResponseAtASpeed",
    "CoaxialConnectionSteadyStateSynchronousResponseAtASpeed",
    "ComponentSteadyStateSynchronousResponseAtASpeed",
    "ConceptCouplingConnectionSteadyStateSynchronousResponseAtASpeed",
    "ConceptCouplingHalfSteadyStateSynchronousResponseAtASpeed",
    "ConceptCouplingSteadyStateSynchronousResponseAtASpeed",
    "ConceptGearMeshSteadyStateSynchronousResponseAtASpeed",
    "ConceptGearSetSteadyStateSynchronousResponseAtASpeed",
    "ConceptGearSteadyStateSynchronousResponseAtASpeed",
    "ConicalGearMeshSteadyStateSynchronousResponseAtASpeed",
    "ConicalGearSetSteadyStateSynchronousResponseAtASpeed",
    "ConicalGearSteadyStateSynchronousResponseAtASpeed",
    "ConnectionSteadyStateSynchronousResponseAtASpeed",
    "ConnectorSteadyStateSynchronousResponseAtASpeed",
    "CouplingConnectionSteadyStateSynchronousResponseAtASpeed",
    "CouplingHalfSteadyStateSynchronousResponseAtASpeed",
    "CouplingSteadyStateSynchronousResponseAtASpeed",
    "CVTBeltConnectionSteadyStateSynchronousResponseAtASpeed",
    "CVTPulleySteadyStateSynchronousResponseAtASpeed",
    "CVTSteadyStateSynchronousResponseAtASpeed",
    "CycloidalAssemblySteadyStateSynchronousResponseAtASpeed",
    "CycloidalDiscCentralBearingConnectionSteadyStateSynchronousResponseAtASpeed",
    "CycloidalDiscPlanetaryBearingConnectionSteadyStateSynchronousResponseAtASpeed",
    "CycloidalDiscSteadyStateSynchronousResponseAtASpeed",
    "CylindricalGearMeshSteadyStateSynchronousResponseAtASpeed",
    "CylindricalGearSetSteadyStateSynchronousResponseAtASpeed",
    "CylindricalGearSteadyStateSynchronousResponseAtASpeed",
    "CylindricalPlanetGearSteadyStateSynchronousResponseAtASpeed",
    "DatumSteadyStateSynchronousResponseAtASpeed",
    "ExternalCADModelSteadyStateSynchronousResponseAtASpeed",
    "FaceGearMeshSteadyStateSynchronousResponseAtASpeed",
    "FaceGearSetSteadyStateSynchronousResponseAtASpeed",
    "FaceGearSteadyStateSynchronousResponseAtASpeed",
    "FEPartSteadyStateSynchronousResponseAtASpeed",
    "FlexiblePinAssemblySteadyStateSynchronousResponseAtASpeed",
    "GearMeshSteadyStateSynchronousResponseAtASpeed",
    "GearSetSteadyStateSynchronousResponseAtASpeed",
    "GearSteadyStateSynchronousResponseAtASpeed",
    "GuideDxfModelSteadyStateSynchronousResponseAtASpeed",
    "HypoidGearMeshSteadyStateSynchronousResponseAtASpeed",
    "HypoidGearSetSteadyStateSynchronousResponseAtASpeed",
    "HypoidGearSteadyStateSynchronousResponseAtASpeed",
    "InterMountableComponentConnectionSteadyStateSynchronousResponseAtASpeed",
    "KlingelnbergCycloPalloidConicalGearMeshSteadyStateSynchronousResponseAtASpeed",
    "KlingelnbergCycloPalloidConicalGearSetSteadyStateSynchronousResponseAtASpeed",
    "KlingelnbergCycloPalloidConicalGearSteadyStateSynchronousResponseAtASpeed",
    "KlingelnbergCycloPalloidHypoidGearMeshSteadyStateSynchronousResponseAtASpeed",
    "KlingelnbergCycloPalloidHypoidGearSetSteadyStateSynchronousResponseAtASpeed",
    "KlingelnbergCycloPalloidHypoidGearSteadyStateSynchronousResponseAtASpeed",
    "KlingelnbergCycloPalloidSpiralBevelGearMeshSteadyStateSynchronousResponseAtASpeed",
    "KlingelnbergCycloPalloidSpiralBevelGearSetSteadyStateSynchronousResponseAtASpeed",
    "KlingelnbergCycloPalloidSpiralBevelGearSteadyStateSynchronousResponseAtASpeed",
    "MassDiscSteadyStateSynchronousResponseAtASpeed",
    "MeasurementComponentSteadyStateSynchronousResponseAtASpeed",
    "MicrophoneArraySteadyStateSynchronousResponseAtASpeed",
    "MicrophoneSteadyStateSynchronousResponseAtASpeed",
    "MountableComponentSteadyStateSynchronousResponseAtASpeed",
    "OilSealSteadyStateSynchronousResponseAtASpeed",
    "PartSteadyStateSynchronousResponseAtASpeed",
    "PartToPartShearCouplingConnectionSteadyStateSynchronousResponseAtASpeed",
    "PartToPartShearCouplingHalfSteadyStateSynchronousResponseAtASpeed",
    "PartToPartShearCouplingSteadyStateSynchronousResponseAtASpeed",
    "PlanetaryConnectionSteadyStateSynchronousResponseAtASpeed",
    "PlanetaryGearSetSteadyStateSynchronousResponseAtASpeed",
    "PlanetCarrierSteadyStateSynchronousResponseAtASpeed",
    "PointLoadSteadyStateSynchronousResponseAtASpeed",
    "PowerLoadSteadyStateSynchronousResponseAtASpeed",
    "PulleySteadyStateSynchronousResponseAtASpeed",
    "RingPinsSteadyStateSynchronousResponseAtASpeed",
    "RingPinsToDiscConnectionSteadyStateSynchronousResponseAtASpeed",
    "RollingRingAssemblySteadyStateSynchronousResponseAtASpeed",
    "RollingRingConnectionSteadyStateSynchronousResponseAtASpeed",
    "RollingRingSteadyStateSynchronousResponseAtASpeed",
    "RootAssemblySteadyStateSynchronousResponseAtASpeed",
    "ShaftHubConnectionSteadyStateSynchronousResponseAtASpeed",
    "ShaftSteadyStateSynchronousResponseAtASpeed",
    "ShaftToMountableComponentConnectionSteadyStateSynchronousResponseAtASpeed",
    "SpecialisedAssemblySteadyStateSynchronousResponseAtASpeed",
    "SpiralBevelGearMeshSteadyStateSynchronousResponseAtASpeed",
    "SpiralBevelGearSetSteadyStateSynchronousResponseAtASpeed",
    "SpiralBevelGearSteadyStateSynchronousResponseAtASpeed",
    "SpringDamperConnectionSteadyStateSynchronousResponseAtASpeed",
    "SpringDamperHalfSteadyStateSynchronousResponseAtASpeed",
    "SpringDamperSteadyStateSynchronousResponseAtASpeed",
    "SteadyStateSynchronousResponseAtASpeed",
    "StraightBevelDiffGearMeshSteadyStateSynchronousResponseAtASpeed",
    "StraightBevelDiffGearSetSteadyStateSynchronousResponseAtASpeed",
    "StraightBevelDiffGearSteadyStateSynchronousResponseAtASpeed",
    "StraightBevelGearMeshSteadyStateSynchronousResponseAtASpeed",
    "StraightBevelGearSetSteadyStateSynchronousResponseAtASpeed",
    "StraightBevelGearSteadyStateSynchronousResponseAtASpeed",
    "StraightBevelPlanetGearSteadyStateSynchronousResponseAtASpeed",
    "StraightBevelSunGearSteadyStateSynchronousResponseAtASpeed",
    "SynchroniserHalfSteadyStateSynchronousResponseAtASpeed",
    "SynchroniserPartSteadyStateSynchronousResponseAtASpeed",
    "SynchroniserSleeveSteadyStateSynchronousResponseAtASpeed",
    "SynchroniserSteadyStateSynchronousResponseAtASpeed",
    "TorqueConverterConnectionSteadyStateSynchronousResponseAtASpeed",
    "TorqueConverterPumpSteadyStateSynchronousResponseAtASpeed",
    "TorqueConverterSteadyStateSynchronousResponseAtASpeed",
    "TorqueConverterTurbineSteadyStateSynchronousResponseAtASpeed",
    "UnbalancedMassSteadyStateSynchronousResponseAtASpeed",
    "VirtualComponentSteadyStateSynchronousResponseAtASpeed",
    "WormGearMeshSteadyStateSynchronousResponseAtASpeed",
    "WormGearSetSteadyStateSynchronousResponseAtASpeed",
    "WormGearSteadyStateSynchronousResponseAtASpeed",
    "ZerolBevelGearMeshSteadyStateSynchronousResponseAtASpeed",
    "ZerolBevelGearSetSteadyStateSynchronousResponseAtASpeed",
    "ZerolBevelGearSteadyStateSynchronousResponseAtASpeed",
)



"""ConicalMeshManufacturingConfig"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal import constructor, utility
from mastapy._private.gears.manufacturing.bevel import _810
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_CONICAL_MESH_MANUFACTURING_CONFIG = python_net_import(
    "SMT.MastaAPI.Gears.Manufacturing.Bevel", "ConicalMeshManufacturingConfig"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.gears.manufacturing.bevel import _811, _817
    from mastapy._private.gears.analysis import _1263, _1260, _1254

    Self = TypeVar("Self", bound="ConicalMeshManufacturingConfig")
    CastSelf = TypeVar(
        "CastSelf",
        bound="ConicalMeshManufacturingConfig._Cast_ConicalMeshManufacturingConfig",
    )


__docformat__ = "restructuredtext en"
__all__ = ("ConicalMeshManufacturingConfig",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_ConicalMeshManufacturingConfig:
    """Special nested class for casting ConicalMeshManufacturingConfig to subclasses."""

    __parent__: "ConicalMeshManufacturingConfig"

    @property
    def conical_mesh_micro_geometry_config_base(
        self: "CastSelf",
    ) -> "_810.ConicalMeshMicroGeometryConfigBase":
        return self.__parent__._cast(_810.ConicalMeshMicroGeometryConfigBase)

    @property
    def gear_mesh_implementation_detail(
        self: "CastSelf",
    ) -> "_1263.GearMeshImplementationDetail":
        from mastapy._private.gears.analysis import _1263

        return self.__parent__._cast(_1263.GearMeshImplementationDetail)

    @property
    def gear_mesh_design_analysis(self: "CastSelf") -> "_1260.GearMeshDesignAnalysis":
        from mastapy._private.gears.analysis import _1260

        return self.__parent__._cast(_1260.GearMeshDesignAnalysis)

    @property
    def abstract_gear_mesh_analysis(
        self: "CastSelf",
    ) -> "_1254.AbstractGearMeshAnalysis":
        from mastapy._private.gears.analysis import _1254

        return self.__parent__._cast(_1254.AbstractGearMeshAnalysis)

    @property
    def conical_mesh_manufacturing_config(
        self: "CastSelf",
    ) -> "ConicalMeshManufacturingConfig":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class ConicalMeshManufacturingConfig(_810.ConicalMeshMicroGeometryConfigBase):
    """ConicalMeshManufacturingConfig

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _CONICAL_MESH_MANUFACTURING_CONFIG

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def pinion_config(self: "Self") -> "_811.ConicalPinionManufacturingConfig":
        """mastapy._private.gears.manufacturing.bevel.ConicalPinionManufacturingConfig

        Note:
            This property is readonly.
        """
        temp = self.wrapped.PinionConfig

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def wheel_config(self: "Self") -> "_817.ConicalWheelManufacturingConfig":
        """mastapy._private.gears.manufacturing.bevel.ConicalWheelManufacturingConfig

        Note:
            This property is readonly.
        """
        temp = self.wrapped.WheelConfig

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def cast_to(self: "Self") -> "_Cast_ConicalMeshManufacturingConfig":
        """Cast to another type.

        Returns:
            _Cast_ConicalMeshManufacturingConfig
        """
        return _Cast_ConicalMeshManufacturingConfig(self)



"""Subpackage."""

from typing import TYPE_CHECKING as __tc


if __tc:
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5499 import (
        AbstractAssemblyMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5500 import (
        AbstractShaftMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5501 import (
        AbstractShaftOrHousingMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5502 import (
        AbstractShaftToMountableComponentConnectionMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5503 import (
        AGMAGleasonConicalGearMeshMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5504 import (
        AGMAGleasonConicalGearMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5505 import (
        AGMAGleasonConicalGearSetMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5506 import (
        AnalysisTypes,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5507 import (
        AssemblyMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5508 import (
        BearingElementOrbitModel,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5509 import (
        BearingMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5510 import (
        BearingStiffnessModel,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5511 import (
        BeltConnectionMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5512 import (
        BeltDriveMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5513 import (
        BevelDifferentialGearMeshMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5514 import (
        BevelDifferentialGearMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5515 import (
        BevelDifferentialGearSetMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5516 import (
        BevelDifferentialPlanetGearMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5517 import (
        BevelDifferentialSunGearMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5518 import (
        BevelGearMeshMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5519 import (
        BevelGearMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5520 import (
        BevelGearSetMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5521 import (
        BoltedJointMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5522 import (
        BoltMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5523 import (
        ClutchConnectionMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5524 import (
        ClutchHalfMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5525 import (
        ClutchMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5526 import (
        ClutchSpringType,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5527 import (
        CoaxialConnectionMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5528 import (
        ComponentMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5529 import (
        ConceptCouplingConnectionMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5530 import (
        ConceptCouplingHalfMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5531 import (
        ConceptCouplingMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5532 import (
        ConceptGearMeshMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5533 import (
        ConceptGearMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5534 import (
        ConceptGearSetMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5535 import (
        ConicalGearMeshMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5536 import (
        ConicalGearMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5537 import (
        ConicalGearSetMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5538 import (
        ConnectionMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5539 import (
        ConnectorMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5540 import (
        CouplingConnectionMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5541 import (
        CouplingHalfMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5542 import (
        CouplingMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5543 import (
        CVTBeltConnectionMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5544 import (
        CVTMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5545 import (
        CVTPulleyMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5546 import (
        CycloidalAssemblyMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5547 import (
        CycloidalDiscCentralBearingConnectionMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5548 import (
        CycloidalDiscMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5549 import (
        CycloidalDiscPlanetaryBearingConnectionMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5550 import (
        CylindricalGearMeshMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5551 import (
        CylindricalGearMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5552 import (
        CylindricalGearSetMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5553 import (
        CylindricalPlanetGearMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5554 import (
        DatumMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5555 import (
        ExternalCADModelMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5556 import (
        FaceGearMeshMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5557 import (
        FaceGearMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5558 import (
        FaceGearSetMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5559 import (
        FEPartMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5560 import (
        FlexiblePinAssemblyMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5561 import (
        GearMeshMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5562 import (
        GearMeshStiffnessModel,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5563 import (
        GearMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5564 import (
        GearSetMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5565 import (
        GuideDxfModelMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5566 import (
        HypoidGearMeshMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5567 import (
        HypoidGearMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5568 import (
        HypoidGearSetMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5569 import (
        InertiaAdjustedLoadCasePeriodMethod,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5570 import (
        InertiaAdjustedLoadCaseResultsToCreate,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5571 import (
        InputSignalFilterLevel,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5572 import (
        InputVelocityForRunUpProcessingType,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5573 import (
        InterMountableComponentConnectionMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5574 import (
        KlingelnbergCycloPalloidConicalGearMeshMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5575 import (
        KlingelnbergCycloPalloidConicalGearMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5576 import (
        KlingelnbergCycloPalloidConicalGearSetMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5577 import (
        KlingelnbergCycloPalloidHypoidGearMeshMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5578 import (
        KlingelnbergCycloPalloidHypoidGearMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5579 import (
        KlingelnbergCycloPalloidHypoidGearSetMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5580 import (
        KlingelnbergCycloPalloidSpiralBevelGearMeshMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5581 import (
        KlingelnbergCycloPalloidSpiralBevelGearMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5582 import (
        KlingelnbergCycloPalloidSpiralBevelGearSetMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5583 import (
        MassDiscMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5584 import (
        MBDAnalysisDrawStyle,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5585 import (
        MBDAnalysisOptions,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5586 import (
        MBDRunUpAnalysisOptions,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5587 import (
        MeasurementComponentMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5588 import (
        MicrophoneArrayMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5589 import (
        MicrophoneMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5590 import (
        MountableComponentMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5591 import (
        MultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5592 import (
        OilSealMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5593 import (
        PartMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5594 import (
        PartToPartShearCouplingConnectionMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5595 import (
        PartToPartShearCouplingHalfMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5596 import (
        PartToPartShearCouplingMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5597 import (
        PlanetaryConnectionMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5598 import (
        PlanetaryGearSetMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5599 import (
        PlanetCarrierMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5600 import (
        PointLoadMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5601 import (
        PowerLoadMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5602 import (
        PulleyMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5603 import (
        RingPinsMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5604 import (
        RingPinsToDiscConnectionMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5605 import (
        RollingRingAssemblyMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5606 import (
        RollingRingConnectionMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5607 import (
        RollingRingMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5608 import (
        RootAssemblyMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5609 import (
        RunUpDrivingMode,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5610 import (
        ShaftAndHousingFlexibilityOption,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5611 import (
        ShaftHubConnectionMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5612 import (
        ShaftMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5613 import (
        ShaftToMountableComponentConnectionMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5614 import (
        ShapeOfInitialAccelerationPeriodForRunUp,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5615 import (
        SpecialisedAssemblyMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5616 import (
        SpiralBevelGearMeshMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5617 import (
        SpiralBevelGearMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5618 import (
        SpiralBevelGearSetMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5619 import (
        SplineDampingOptions,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5620 import (
        SpringDamperConnectionMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5621 import (
        SpringDamperHalfMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5622 import (
        SpringDamperMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5623 import (
        StraightBevelDiffGearMeshMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5624 import (
        StraightBevelDiffGearMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5625 import (
        StraightBevelDiffGearSetMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5626 import (
        StraightBevelGearMeshMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5627 import (
        StraightBevelGearMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5628 import (
        StraightBevelGearSetMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5629 import (
        StraightBevelPlanetGearMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5630 import (
        StraightBevelSunGearMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5631 import (
        SynchroniserHalfMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5632 import (
        SynchroniserMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5633 import (
        SynchroniserPartMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5634 import (
        SynchroniserSleeveMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5635 import (
        TorqueConverterConnectionMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5636 import (
        TorqueConverterLockupRule,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5637 import (
        TorqueConverterMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5638 import (
        TorqueConverterPumpMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5639 import (
        TorqueConverterStatus,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5640 import (
        TorqueConverterTurbineMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5641 import (
        UnbalancedMassMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5642 import (
        VirtualComponentMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5643 import (
        WheelSlipType,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5644 import (
        WormGearMeshMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5645 import (
        WormGearMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5646 import (
        WormGearSetMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5647 import (
        ZerolBevelGearMeshMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5648 import (
        ZerolBevelGearMultibodyDynamicsAnalysis,
    )
    from mastapy._private.system_model.analyses_and_results.mbd_analyses._5649 import (
        ZerolBevelGearSetMultibodyDynamicsAnalysis,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.system_model.analyses_and_results.mbd_analyses._5499": [
            "AbstractAssemblyMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5500": [
            "AbstractShaftMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5501": [
            "AbstractShaftOrHousingMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5502": [
            "AbstractShaftToMountableComponentConnectionMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5503": [
            "AGMAGleasonConicalGearMeshMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5504": [
            "AGMAGleasonConicalGearMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5505": [
            "AGMAGleasonConicalGearSetMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5506": [
            "AnalysisTypes"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5507": [
            "AssemblyMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5508": [
            "BearingElementOrbitModel"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5509": [
            "BearingMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5510": [
            "BearingStiffnessModel"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5511": [
            "BeltConnectionMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5512": [
            "BeltDriveMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5513": [
            "BevelDifferentialGearMeshMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5514": [
            "BevelDifferentialGearMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5515": [
            "BevelDifferentialGearSetMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5516": [
            "BevelDifferentialPlanetGearMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5517": [
            "BevelDifferentialSunGearMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5518": [
            "BevelGearMeshMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5519": [
            "BevelGearMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5520": [
            "BevelGearSetMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5521": [
            "BoltedJointMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5522": [
            "BoltMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5523": [
            "ClutchConnectionMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5524": [
            "ClutchHalfMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5525": [
            "ClutchMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5526": [
            "ClutchSpringType"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5527": [
            "CoaxialConnectionMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5528": [
            "ComponentMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5529": [
            "ConceptCouplingConnectionMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5530": [
            "ConceptCouplingHalfMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5531": [
            "ConceptCouplingMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5532": [
            "ConceptGearMeshMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5533": [
            "ConceptGearMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5534": [
            "ConceptGearSetMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5535": [
            "ConicalGearMeshMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5536": [
            "ConicalGearMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5537": [
            "ConicalGearSetMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5538": [
            "ConnectionMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5539": [
            "ConnectorMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5540": [
            "CouplingConnectionMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5541": [
            "CouplingHalfMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5542": [
            "CouplingMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5543": [
            "CVTBeltConnectionMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5544": [
            "CVTMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5545": [
            "CVTPulleyMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5546": [
            "CycloidalAssemblyMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5547": [
            "CycloidalDiscCentralBearingConnectionMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5548": [
            "CycloidalDiscMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5549": [
            "CycloidalDiscPlanetaryBearingConnectionMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5550": [
            "CylindricalGearMeshMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5551": [
            "CylindricalGearMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5552": [
            "CylindricalGearSetMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5553": [
            "CylindricalPlanetGearMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5554": [
            "DatumMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5555": [
            "ExternalCADModelMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5556": [
            "FaceGearMeshMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5557": [
            "FaceGearMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5558": [
            "FaceGearSetMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5559": [
            "FEPartMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5560": [
            "FlexiblePinAssemblyMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5561": [
            "GearMeshMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5562": [
            "GearMeshStiffnessModel"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5563": [
            "GearMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5564": [
            "GearSetMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5565": [
            "GuideDxfModelMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5566": [
            "HypoidGearMeshMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5567": [
            "HypoidGearMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5568": [
            "HypoidGearSetMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5569": [
            "InertiaAdjustedLoadCasePeriodMethod"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5570": [
            "InertiaAdjustedLoadCaseResultsToCreate"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5571": [
            "InputSignalFilterLevel"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5572": [
            "InputVelocityForRunUpProcessingType"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5573": [
            "InterMountableComponentConnectionMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5574": [
            "KlingelnbergCycloPalloidConicalGearMeshMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5575": [
            "KlingelnbergCycloPalloidConicalGearMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5576": [
            "KlingelnbergCycloPalloidConicalGearSetMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5577": [
            "KlingelnbergCycloPalloidHypoidGearMeshMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5578": [
            "KlingelnbergCycloPalloidHypoidGearMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5579": [
            "KlingelnbergCycloPalloidHypoidGearSetMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5580": [
            "KlingelnbergCycloPalloidSpiralBevelGearMeshMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5581": [
            "KlingelnbergCycloPalloidSpiralBevelGearMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5582": [
            "KlingelnbergCycloPalloidSpiralBevelGearSetMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5583": [
            "MassDiscMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5584": [
            "MBDAnalysisDrawStyle"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5585": [
            "MBDAnalysisOptions"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5586": [
            "MBDRunUpAnalysisOptions"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5587": [
            "MeasurementComponentMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5588": [
            "MicrophoneArrayMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5589": [
            "MicrophoneMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5590": [
            "MountableComponentMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5591": [
            "MultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5592": [
            "OilSealMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5593": [
            "PartMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5594": [
            "PartToPartShearCouplingConnectionMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5595": [
            "PartToPartShearCouplingHalfMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5596": [
            "PartToPartShearCouplingMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5597": [
            "PlanetaryConnectionMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5598": [
            "PlanetaryGearSetMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5599": [
            "PlanetCarrierMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5600": [
            "PointLoadMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5601": [
            "PowerLoadMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5602": [
            "PulleyMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5603": [
            "RingPinsMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5604": [
            "RingPinsToDiscConnectionMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5605": [
            "RollingRingAssemblyMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5606": [
            "RollingRingConnectionMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5607": [
            "RollingRingMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5608": [
            "RootAssemblyMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5609": [
            "RunUpDrivingMode"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5610": [
            "ShaftAndHousingFlexibilityOption"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5611": [
            "ShaftHubConnectionMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5612": [
            "ShaftMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5613": [
            "ShaftToMountableComponentConnectionMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5614": [
            "ShapeOfInitialAccelerationPeriodForRunUp"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5615": [
            "SpecialisedAssemblyMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5616": [
            "SpiralBevelGearMeshMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5617": [
            "SpiralBevelGearMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5618": [
            "SpiralBevelGearSetMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5619": [
            "SplineDampingOptions"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5620": [
            "SpringDamperConnectionMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5621": [
            "SpringDamperHalfMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5622": [
            "SpringDamperMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5623": [
            "StraightBevelDiffGearMeshMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5624": [
            "StraightBevelDiffGearMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5625": [
            "StraightBevelDiffGearSetMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5626": [
            "StraightBevelGearMeshMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5627": [
            "StraightBevelGearMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5628": [
            "StraightBevelGearSetMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5629": [
            "StraightBevelPlanetGearMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5630": [
            "StraightBevelSunGearMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5631": [
            "SynchroniserHalfMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5632": [
            "SynchroniserMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5633": [
            "SynchroniserPartMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5634": [
            "SynchroniserSleeveMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5635": [
            "TorqueConverterConnectionMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5636": [
            "TorqueConverterLockupRule"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5637": [
            "TorqueConverterMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5638": [
            "TorqueConverterPumpMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5639": [
            "TorqueConverterStatus"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5640": [
            "TorqueConverterTurbineMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5641": [
            "UnbalancedMassMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5642": [
            "VirtualComponentMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5643": [
            "WheelSlipType"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5644": [
            "WormGearMeshMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5645": [
            "WormGearMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5646": [
            "WormGearSetMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5647": [
            "ZerolBevelGearMeshMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5648": [
            "ZerolBevelGearMultibodyDynamicsAnalysis"
        ],
        "_private.system_model.analyses_and_results.mbd_analyses._5649": [
            "ZerolBevelGearSetMultibodyDynamicsAnalysis"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "AbstractAssemblyMultibodyDynamicsAnalysis",
    "AbstractShaftMultibodyDynamicsAnalysis",
    "AbstractShaftOrHousingMultibodyDynamicsAnalysis",
    "AbstractShaftToMountableComponentConnectionMultibodyDynamicsAnalysis",
    "AGMAGleasonConicalGearMeshMultibodyDynamicsAnalysis",
    "AGMAGleasonConicalGearMultibodyDynamicsAnalysis",
    "AGMAGleasonConicalGearSetMultibodyDynamicsAnalysis",
    "AnalysisTypes",
    "AssemblyMultibodyDynamicsAnalysis",
    "BearingElementOrbitModel",
    "BearingMultibodyDynamicsAnalysis",
    "BearingStiffnessModel",
    "BeltConnectionMultibodyDynamicsAnalysis",
    "BeltDriveMultibodyDynamicsAnalysis",
    "BevelDifferentialGearMeshMultibodyDynamicsAnalysis",
    "BevelDifferentialGearMultibodyDynamicsAnalysis",
    "BevelDifferentialGearSetMultibodyDynamicsAnalysis",
    "BevelDifferentialPlanetGearMultibodyDynamicsAnalysis",
    "BevelDifferentialSunGearMultibodyDynamicsAnalysis",
    "BevelGearMeshMultibodyDynamicsAnalysis",
    "BevelGearMultibodyDynamicsAnalysis",
    "BevelGearSetMultibodyDynamicsAnalysis",
    "BoltedJointMultibodyDynamicsAnalysis",
    "BoltMultibodyDynamicsAnalysis",
    "ClutchConnectionMultibodyDynamicsAnalysis",
    "ClutchHalfMultibodyDynamicsAnalysis",
    "ClutchMultibodyDynamicsAnalysis",
    "ClutchSpringType",
    "CoaxialConnectionMultibodyDynamicsAnalysis",
    "ComponentMultibodyDynamicsAnalysis",
    "ConceptCouplingConnectionMultibodyDynamicsAnalysis",
    "ConceptCouplingHalfMultibodyDynamicsAnalysis",
    "ConceptCouplingMultibodyDynamicsAnalysis",
    "ConceptGearMeshMultibodyDynamicsAnalysis",
    "ConceptGearMultibodyDynamicsAnalysis",
    "ConceptGearSetMultibodyDynamicsAnalysis",
    "ConicalGearMeshMultibodyDynamicsAnalysis",
    "ConicalGearMultibodyDynamicsAnalysis",
    "ConicalGearSetMultibodyDynamicsAnalysis",
    "ConnectionMultibodyDynamicsAnalysis",
    "ConnectorMultibodyDynamicsAnalysis",
    "CouplingConnectionMultibodyDynamicsAnalysis",
    "CouplingHalfMultibodyDynamicsAnalysis",
    "CouplingMultibodyDynamicsAnalysis",
    "CVTBeltConnectionMultibodyDynamicsAnalysis",
    "CVTMultibodyDynamicsAnalysis",
    "CVTPulleyMultibodyDynamicsAnalysis",
    "CycloidalAssemblyMultibodyDynamicsAnalysis",
    "CycloidalDiscCentralBearingConnectionMultibodyDynamicsAnalysis",
    "CycloidalDiscMultibodyDynamicsAnalysis",
    "CycloidalDiscPlanetaryBearingConnectionMultibodyDynamicsAnalysis",
    "CylindricalGearMeshMultibodyDynamicsAnalysis",
    "CylindricalGearMultibodyDynamicsAnalysis",
    "CylindricalGearSetMultibodyDynamicsAnalysis",
    "CylindricalPlanetGearMultibodyDynamicsAnalysis",
    "DatumMultibodyDynamicsAnalysis",
    "ExternalCADModelMultibodyDynamicsAnalysis",
    "FaceGearMeshMultibodyDynamicsAnalysis",
    "FaceGearMultibodyDynamicsAnalysis",
    "FaceGearSetMultibodyDynamicsAnalysis",
    "FEPartMultibodyDynamicsAnalysis",
    "FlexiblePinAssemblyMultibodyDynamicsAnalysis",
    "GearMeshMultibodyDynamicsAnalysis",
    "GearMeshStiffnessModel",
    "GearMultibodyDynamicsAnalysis",
    "GearSetMultibodyDynamicsAnalysis",
    "GuideDxfModelMultibodyDynamicsAnalysis",
    "HypoidGearMeshMultibodyDynamicsAnalysis",
    "HypoidGearMultibodyDynamicsAnalysis",
    "HypoidGearSetMultibodyDynamicsAnalysis",
    "InertiaAdjustedLoadCasePeriodMethod",
    "InertiaAdjustedLoadCaseResultsToCreate",
    "InputSignalFilterLevel",
    "InputVelocityForRunUpProcessingType",
    "InterMountableComponentConnectionMultibodyDynamicsAnalysis",
    "KlingelnbergCycloPalloidConicalGearMeshMultibodyDynamicsAnalysis",
    "KlingelnbergCycloPalloidConicalGearMultibodyDynamicsAnalysis",
    "KlingelnbergCycloPalloidConicalGearSetMultibodyDynamicsAnalysis",
    "KlingelnbergCycloPalloidHypoidGearMeshMultibodyDynamicsAnalysis",
    "KlingelnbergCycloPalloidHypoidGearMultibodyDynamicsAnalysis",
    "KlingelnbergCycloPalloidHypoidGearSetMultibodyDynamicsAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearMeshMultibodyDynamicsAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearMultibodyDynamicsAnalysis",
    "KlingelnbergCycloPalloidSpiralBevelGearSetMultibodyDynamicsAnalysis",
    "MassDiscMultibodyDynamicsAnalysis",
    "MBDAnalysisDrawStyle",
    "MBDAnalysisOptions",
    "MBDRunUpAnalysisOptions",
    "MeasurementComponentMultibodyDynamicsAnalysis",
    "MicrophoneArrayMultibodyDynamicsAnalysis",
    "MicrophoneMultibodyDynamicsAnalysis",
    "MountableComponentMultibodyDynamicsAnalysis",
    "MultibodyDynamicsAnalysis",
    "OilSealMultibodyDynamicsAnalysis",
    "PartMultibodyDynamicsAnalysis",
    "PartToPartShearCouplingConnectionMultibodyDynamicsAnalysis",
    "PartToPartShearCouplingHalfMultibodyDynamicsAnalysis",
    "PartToPartShearCouplingMultibodyDynamicsAnalysis",
    "PlanetaryConnectionMultibodyDynamicsAnalysis",
    "PlanetaryGearSetMultibodyDynamicsAnalysis",
    "PlanetCarrierMultibodyDynamicsAnalysis",
    "PointLoadMultibodyDynamicsAnalysis",
    "PowerLoadMultibodyDynamicsAnalysis",
    "PulleyMultibodyDynamicsAnalysis",
    "RingPinsMultibodyDynamicsAnalysis",
    "RingPinsToDiscConnectionMultibodyDynamicsAnalysis",
    "RollingRingAssemblyMultibodyDynamicsAnalysis",
    "RollingRingConnectionMultibodyDynamicsAnalysis",
    "RollingRingMultibodyDynamicsAnalysis",
    "RootAssemblyMultibodyDynamicsAnalysis",
    "RunUpDrivingMode",
    "ShaftAndHousingFlexibilityOption",
    "ShaftHubConnectionMultibodyDynamicsAnalysis",
    "ShaftMultibodyDynamicsAnalysis",
    "ShaftToMountableComponentConnectionMultibodyDynamicsAnalysis",
    "ShapeOfInitialAccelerationPeriodForRunUp",
    "SpecialisedAssemblyMultibodyDynamicsAnalysis",
    "SpiralBevelGearMeshMultibodyDynamicsAnalysis",
    "SpiralBevelGearMultibodyDynamicsAnalysis",
    "SpiralBevelGearSetMultibodyDynamicsAnalysis",
    "SplineDampingOptions",
    "SpringDamperConnectionMultibodyDynamicsAnalysis",
    "SpringDamperHalfMultibodyDynamicsAnalysis",
    "SpringDamperMultibodyDynamicsAnalysis",
    "StraightBevelDiffGearMeshMultibodyDynamicsAnalysis",
    "StraightBevelDiffGearMultibodyDynamicsAnalysis",
    "StraightBevelDiffGearSetMultibodyDynamicsAnalysis",
    "StraightBevelGearMeshMultibodyDynamicsAnalysis",
    "StraightBevelGearMultibodyDynamicsAnalysis",
    "StraightBevelGearSetMultibodyDynamicsAnalysis",
    "StraightBevelPlanetGearMultibodyDynamicsAnalysis",
    "StraightBevelSunGearMultibodyDynamicsAnalysis",
    "SynchroniserHalfMultibodyDynamicsAnalysis",
    "SynchroniserMultibodyDynamicsAnalysis",
    "SynchroniserPartMultibodyDynamicsAnalysis",
    "SynchroniserSleeveMultibodyDynamicsAnalysis",
    "TorqueConverterConnectionMultibodyDynamicsAnalysis",
    "TorqueConverterLockupRule",
    "TorqueConverterMultibodyDynamicsAnalysis",
    "TorqueConverterPumpMultibodyDynamicsAnalysis",
    "TorqueConverterStatus",
    "TorqueConverterTurbineMultibodyDynamicsAnalysis",
    "UnbalancedMassMultibodyDynamicsAnalysis",
    "VirtualComponentMultibodyDynamicsAnalysis",
    "WheelSlipType",
    "WormGearMeshMultibodyDynamicsAnalysis",
    "WormGearMultibodyDynamicsAnalysis",
    "WormGearSetMultibodyDynamicsAnalysis",
    "ZerolBevelGearMeshMultibodyDynamicsAnalysis",
    "ZerolBevelGearMultibodyDynamicsAnalysis",
    "ZerolBevelGearSetMultibodyDynamicsAnalysis",
)



"""FESubstructureNodeModeShapes"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal import constructor, conversion, utility
from mastapy._private import _0
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_FE_SUBSTRUCTURE_NODE_MODE_SHAPES = python_net_import(
    "SMT.MastaAPI.SystemModel.FE", "FESubstructureNodeModeShapes"
)

if TYPE_CHECKING:
    from typing import Any, Type, List, TypeVar

    from mastapy._private.system_model.fe import _2439, _2440
    from mastapy._private.math_utility import _1545

    Self = TypeVar("Self", bound="FESubstructureNodeModeShapes")
    CastSelf = TypeVar(
        "CastSelf",
        bound="FESubstructureNodeModeShapes._Cast_FESubstructureNodeModeShapes",
    )


__docformat__ = "restructuredtext en"
__all__ = ("FESubstructureNodeModeShapes",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_FESubstructureNodeModeShapes:
    """Special nested class for casting FESubstructureNodeModeShapes to subclasses."""

    __parent__: "FESubstructureNodeModeShapes"

    @property
    def fe_substructure_node_mode_shapes(
        self: "CastSelf",
    ) -> "FESubstructureNodeModeShapes":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class FESubstructureNodeModeShapes(_0.APIBase):
    """FESubstructureNodeModeShapes

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _FE_SUBSTRUCTURE_NODE_MODE_SHAPES

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def condensation_node(self: "Self") -> "_2439.FESubstructureNode":
        """mastapy._private.system_model.fe.FESubstructureNode

        Note:
            This property is readonly.
        """
        temp = self.wrapped.CondensationNode

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def connected_component_local_coordinate_system(
        self: "Self",
    ) -> "_1545.CoordinateSystem3D":
        """mastapy._private.math_utility.CoordinateSystem3D

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ConnectedComponentLocalCoordinateSystem

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def mode_shapes_at_condensation_node(
        self: "Self",
    ) -> "List[_2440.FESubstructureNodeModeShape]":
        """List[mastapy._private.system_model.fe.FESubstructureNodeModeShape]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ModeShapesAtCondensationNode

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(self: "Self") -> "_Cast_FESubstructureNodeModeShapes":
        """Cast to another type.

        Returns:
            _Cast_FESubstructureNodeModeShapes
        """
        return _Cast_FESubstructureNodeModeShapes(self)



"""DynamicsResponseScalarResult"""
from __future__ import annotations

from typing import TYPE_CHECKING
from enum import Enum

from mastapy._private._internal.python_net import python_net_import

_DYNAMICS_RESPONSE_SCALAR_RESULT = python_net_import(
    "SMT.MastaAPI.MathUtility", "DynamicsResponseScalarResult"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="DynamicsResponseScalarResult")
    CastSelf = TypeVar(
        "CastSelf",
        bound="DynamicsResponseScalarResult._Cast_DynamicsResponseScalarResult",
    )


__docformat__ = "restructuredtext en"
__all__ = ("DynamicsResponseScalarResult",)


class DynamicsResponseScalarResult(Enum):
    """DynamicsResponseScalarResult

    This is a mastapy class.

    Note:
        This class is an Enum.
    """

    @classmethod
    def type_(cls) -> "Type":
        return _DYNAMICS_RESPONSE_SCALAR_RESULT

    X = 0
    Y = 1
    Z = 2
    ΘX = 3
    ΘY = 4
    ΘZ = 5
    MAGNITUDE_XYZ = 6
    MAGNITUDE_XY = 7
    MAGNITUDE_ΘXΘYΘZ = 8
    MAGNITUDE_ΘX_ΘY = 9


def __enum_setattr(self: "Self", attr: str, value: "Any") -> None:
    raise AttributeError("Cannot set the attributes of an Enum.") from None


def __enum_delattr(self: "Self", attr: str) -> None:
    raise AttributeError("Cannot delete the attributes of an Enum.") from None


DynamicsResponseScalarResult.__setattr__ = __enum_setattr
DynamicsResponseScalarResult.__delattr__ = __enum_delattr



"""HypoidGearDesign"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.type_enforcement import enforce_parameter_types
from mastapy._private._internal import utility
from mastapy._private.gears.gear_designs.agma_gleason_conical import _1231
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_HYPOID_GEAR_DESIGN = python_net_import(
    "SMT.MastaAPI.Gears.GearDesigns.Hypoid", "HypoidGearDesign"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.gears.gear_designs.conical import _1192
    from mastapy._private.gears.gear_designs import _971, _972

    Self = TypeVar("Self", bound="HypoidGearDesign")
    CastSelf = TypeVar("CastSelf", bound="HypoidGearDesign._Cast_HypoidGearDesign")


__docformat__ = "restructuredtext en"
__all__ = ("HypoidGearDesign",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_HypoidGearDesign:
    """Special nested class for casting HypoidGearDesign to subclasses."""

    __parent__: "HypoidGearDesign"

    @property
    def agma_gleason_conical_gear_design(
        self: "CastSelf",
    ) -> "_1231.AGMAGleasonConicalGearDesign":
        return self.__parent__._cast(_1231.AGMAGleasonConicalGearDesign)

    @property
    def conical_gear_design(self: "CastSelf") -> "_1192.ConicalGearDesign":
        from mastapy._private.gears.gear_designs.conical import _1192

        return self.__parent__._cast(_1192.ConicalGearDesign)

    @property
    def gear_design(self: "CastSelf") -> "_971.GearDesign":
        from mastapy._private.gears.gear_designs import _971

        return self.__parent__._cast(_971.GearDesign)

    @property
    def gear_design_component(self: "CastSelf") -> "_972.GearDesignComponent":
        from mastapy._private.gears.gear_designs import _972

        return self.__parent__._cast(_972.GearDesignComponent)

    @property
    def hypoid_gear_design(self: "CastSelf") -> "HypoidGearDesign":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class HypoidGearDesign(_1231.AGMAGleasonConicalGearDesign):
    """HypoidGearDesign

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _HYPOID_GEAR_DESIGN

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def addendum(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Addendum

        if temp is None:
            return 0.0

        return temp

    @property
    def addendum_angle(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.AddendumAngle

        if temp is None:
            return 0.0

        return temp

    @property
    def crown_to_crossing_point(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.CrownToCrossingPoint

        if temp is None:
            return 0.0

        return temp

    @property
    def dedendum(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Dedendum

        if temp is None:
            return 0.0

        return temp

    @property
    def dedendum_angle(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.DedendumAngle

        if temp is None:
            return 0.0

        return temp

    @property
    def face_angle(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.FaceAngle

        if temp is None:
            return 0.0

        return temp

    @property
    def face_apex_to_crossing_point(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.FaceApexToCrossingPoint

        if temp is None:
            return 0.0

        return temp

    @property
    def face_width(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.FaceWidth

        if temp is None:
            return 0.0

        return temp

    @face_width.setter
    @enforce_parameter_types
    def face_width(self: "Self", value: "float") -> None:
        self.wrapped.FaceWidth = float(value) if value is not None else 0.0

    @property
    def front_crown_to_crossing_point(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.FrontCrownToCrossingPoint

        if temp is None:
            return 0.0

        return temp

    @property
    def geometry_factor_j(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.GeometryFactorJ

        if temp is None:
            return 0.0

        return temp

    @property
    def inner_cone_distance(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.InnerConeDistance

        if temp is None:
            return 0.0

        return temp

    @property
    def mean_addendum(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MeanAddendum

        if temp is None:
            return 0.0

        return temp

    @property
    def mean_cone_distance(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MeanConeDistance

        if temp is None:
            return 0.0

        return temp

    @property
    def mean_dedendum(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MeanDedendum

        if temp is None:
            return 0.0

        return temp

    @property
    def mean_normal_circular_thickness(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MeanNormalCircularThickness

        if temp is None:
            return 0.0

        return temp

    @property
    def mean_normal_topland(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MeanNormalTopland

        if temp is None:
            return 0.0

        return temp

    @property
    def mean_pitch_diameter(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MeanPitchDiameter

        if temp is None:
            return 0.0

        return temp

    @property
    def mean_point_to_crossing_point(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MeanPointToCrossingPoint

        if temp is None:
            return 0.0

        return temp

    @property
    def mean_radius(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MeanRadius

        if temp is None:
            return 0.0

        return temp

    @property
    def mean_root_spiral_angle(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MeanRootSpiralAngle

        if temp is None:
            return 0.0

        return temp

    @property
    def mean_spiral_angle(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.MeanSpiralAngle

        if temp is None:
            return 0.0

        return temp

    @property
    def offset_angle_in_axial_plane(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.OffsetAngleInAxialPlane

        if temp is None:
            return 0.0

        return temp

    @property
    def outer_cone_distance(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.OuterConeDistance

        if temp is None:
            return 0.0

        return temp

    @property
    def outer_tip_diameter(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.OuterTipDiameter

        if temp is None:
            return 0.0

        return temp

    @property
    def outer_whole_depth(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.OuterWholeDepth

        if temp is None:
            return 0.0

        return temp

    @property
    def outer_working_depth(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.OuterWorkingDepth

        if temp is None:
            return 0.0

        return temp

    @property
    def pitch_angle(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.PitchAngle

        if temp is None:
            return 0.0

        return temp

    @property
    def pitch_apex_to_crossing_point(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.PitchApexToCrossingPoint

        if temp is None:
            return 0.0

        return temp

    @property
    def pitch_apex_to_crown(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.PitchApexToCrown

        if temp is None:
            return 0.0

        return temp

    @property
    def pitch_diameter(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.PitchDiameter

        if temp is None:
            return 0.0

        return temp

    @property
    def root_apex_to_crossing_point(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.RootApexToCrossingPoint

        if temp is None:
            return 0.0

        return temp

    @property
    def strength_factor_q(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.StrengthFactorQ

        if temp is None:
            return 0.0

        return temp

    @property
    def cast_to(self: "Self") -> "_Cast_HypoidGearDesign":
        """Cast to another type.

        Returns:
            _Cast_HypoidGearDesign
        """
        return _Cast_HypoidGearDesign(self)
